@@ -23,6 +23,8 @@ from __future__ import (print_function, unicode_literals)
 import os, sys, json, traceback, errno
 from .packages import requests
 
+import dxpy
+
 EXPECTED_ERR_EXIT_STATUS = 3
 
 class DXError(Exception):
@@ -218,9 +220,7 @@ def err_exit(message='', code=None, expected_exceptions=default_expected_excepti
 
     exc = exception if exception is not None else sys.exc_info()[1]
     if isinstance(exc, expected_exceptions):
-        exit_with_exc_info(EXPECTED_ERR_EXIT_STATUS, message,
-                           print_tb=True if '_DX_DEBUG' in os.environ else False,
-                           exception=exception)
+        exit_with_exc_info(EXPECTED_ERR_EXIT_STATUS, message, print_tb=dxpy._DEBUG > 0, exception=exception)
     elif ignore_sigpipe and isinstance(exc, IOError) and getattr(exc, 'errno', None) == errno.EPIPE:
         sys.exit(3)
     else:
